//---------------------------------------------------------------------------
//
// Evj        Model the evolution of DNA binding site recognition
//
// Module:    PosInfo, a record to contain information about one
//            position in a genetic sequence
// Author:    Paul C. Anagnostopoulos
// Created:   13 April 2005
//
// This computer program fits the description in the U.S. Copyright Act
// of a "United States Government work." It was written as a part of
// my/our official duties as a Government employee. This means it cannot
// be copyrighted. The program is freely available for use without a
// copyright notice, and there are no restrictions on its use, now or
// subsequently. We retain no rights in the program. Please acknowledge
// the source of this code in any releases you make.
//
//---------------------------------------------------------------------------


// This class is basically just a record. It contains information about
// one position in a genetic sequence, so that the information can be
// conveyed from the simulator to other parts of Evj.

public class PosInfo implements Comparable
{
  // These are the various types of positions in the sequence.
  
  public static final int GENE_WEIGHT       = 1,
                          GENE_THRESHOLD    = 2,
                          SITE_UNMATCHED    = 3,
                          SITE_MATCHED      = 4,
                          NONSITE_UNMATCHED = 5,
                          NONSITE_MATCHED   = 6;

  // This is the information in the record.
  
  public int position;        // Position index.
  public int width;           // Width of site.
  public int type;            // Type of site (see above).
  public int weight;          // Weight or valuation.

  // The constructor simply initializes the record.

  public PosInfo (int position, int width, int type, int weight)
  {
    this.position = position;
    this.width    = width;
    this.type     = type;
    this.weight   = weight;
  }

  // This class implements Comparable so we can sort a bunch of the
  // records. They are sorted by position.

  public int compareTo (Object p)
  {
    int other = ((PosInfo)p).position;

    return (this.position < other) ? -1 : ((this.position > other) ? 1 : 0);
  }
}
